@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v1.3.3'; # TRIAL
+our $VERSION = 'v1.3.4'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -1226,8 +1226,8 @@ sub drop {
 #pod =method ordered_bulk
 #pod
 #pod     $bulk = $coll->ordered_bulk;
-#pod     $bulk->insert( $doc1 );
-#pod     $bulk->insert( $doc2 );
+#pod     $bulk->insert_one( $doc1 );
+#pod     $bulk->insert_one( $doc2 );
 #pod     ...
 #pod     $result = $bulk->execute;
 #pod
@@ -1829,7 +1829,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v1.3.3
+version v1.3.4
 
 =head1 SYNOPSIS
 
@@ -1881,7 +1881,7 @@ are recommended:
     use Safe::Isa; # provides $_isa
 
     try {
-        $coll->insert( $doc )
+        $coll->insert_one( $doc )
     }
     catch {
         if ( $_->$_isa("MongoDB::DuplicateKeyError" ) {
@@ -2572,8 +2572,8 @@ Deletes a collection as well as all of its indexes.
 =head2 ordered_bulk
 
     $bulk = $coll->ordered_bulk;
-    $bulk->insert( $doc1 );
-    $bulk->insert( $doc2 );
+    $bulk->insert_one( $doc1 );
+    $bulk->insert_one( $doc2 );
     ...
     $result = $bulk->execute;
 
