@@ -20,7 +20,7 @@ package MongoDB::Op::_BatchInsert;
 # MongoDB::InsertManyResult
 
 use version;
-our $VERSION = 'v1.3.3'; # TRIAL
+our $VERSION = 'v1.3.4'; # TRIAL
 
 use Moo;
 
@@ -86,7 +86,7 @@ has _doc_ids => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteOp
+  MongoDB::Role::_WriteCommand
   MongoDB::Role::_InsertPreEncoder
 );
 
