@@ -20,7 +20,7 @@ package MongoDB::Op::_InsertOne;
 # MongoDB::InsertOneResult
 
 use version;
-our $VERSION = 'v1.3.3'; # TRIAL
+our $VERSION = 'v1.3.4'; # TRIAL
 
 use Moo;
 
@@ -68,7 +68,7 @@ has _doc_id => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteOp
+  MongoDB::Role::_WriteCommand
   MongoDB::Role::_InsertPreEncoder
   MongoDB::Role::_BypassValidation
 );
