@@ -19,7 +19,7 @@ package MongoDB::Op::_Update;
 # Encapsulate an update operation; returns a MongoDB::UpdateResult
 
 use version;
-our $VERSION = 'v1.3.3'; # TRIAL
+our $VERSION = 'v1.3.4'; # TRIAL
 
 use Moo;
 
@@ -85,7 +85,7 @@ has upsert => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteOp
+  MongoDB::Role::_WriteCommand
   MongoDB::Role::_UpdatePreEncoder
   MongoDB::Role::_BypassValidation
 );
