@@ -25,7 +25,7 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v1.3.3'; # TRIAL
+our $VERSION = 'v1.3.4'; # TRIAL
 
 use Moo;
 use Errno qw[EINTR EPIPE];
@@ -274,11 +274,6 @@ sub is_connected {
     return $self->connected && $self->fh;
 }
 
-sub idle_time_sec {
-    my ($self) = @_;
-    return( time - $self->last_used );
-}
-
 sub write {
     my ( $self, $buf ) = @_;
 
